/**
 * bookshelf/app.js
 *
 * Timothy J. Griesser
 * tgriesser@cs50.harvard.edu
 *
 * Demonstration of Bookshelf.js
 */
var http = require('http');
var _    = require('underscore');
var app = require('./init/express');

var Course = require('./models/course');
var Instructor = require('./models/instructor');
var Meeting = require('./models/meeting');
var Requirements = require('./models/requirements');

function renderCourses(req, res) {
	Course.collection().query('limit', 20).fetch().then(function(courses) {
		return courses.load(['instructors']);
	}).then(function(courses) {
		res.render('index', {courses: courses});
	}).catch(function(e) {
		console.log(e.stack);
		res.json(400, {error: e.message});
	});
}

// GET /
app.get('/', renderCourses);
app.get('/courses', renderCourses);

app.get('/json/course/:id', function(req, res) {
	new Course({id: req.params.id}).fetch({
		withRelated: 'instructors',
		require: true
	}).then(function(course) {
		res.json(course);
	}).catch(function(e) {
		console.log(e.stack)
		res.json(400, {error: e.message});
	});
});

app.get('/course/:id', function(req, res) {
	new Course({id: req.params.id}).fetch({withRelated: 'instructors', require: true}).then(function(course) {
		res.render('course', {course: course});
	}).catch(function(e) {
		res.json(400, {error: e.message});
	});
});

app.post('/course/:id', function(req, res) {
	new Course({id: req.params.id}).fetch({require: true}).then(function(course) {
		return course.save(_.pick(req.body, 'title', 'description'));
	})
    .then(function(course) {
    	res.json(course);
    }).catch(function(e) {
    	console.log(e.stack);
    	res.json(400, {error: e.message});
    })
});


http.createServer(app).listen(app.get('port'), function(){
  console.log('Express server listening on port ' + app.get('port'));
});
